# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.virtual_zones import VirtualZones


class ActionablePolicy(object):

    """Implementation of the 'ActionablePolicy' model.

    TODO: type model description here.

    Attributes:
        actionable_id (int): TODO: type description here.
        role_number (int): TODO: type description here.
        role_name (string): TODO: type description here.
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        site_id (int): TODO: type description here.
        action (int): TODO: type description here.
        active (bool): TODO: type description here.
        approved_user_id (int): TODO: type description here.
        approved_username (string): TODO: type description here.
        categories (list of int): TODO: type description here.
        categories_access (list of int): TODO: type description here.
        cloud_reputation (int): TODO: type description here.
        created_user_id (int): TODO: type description here.
        created_username (string): TODO: type description here.
        description (string): TODO: type description here.
        full_match (bool): TODO: type description here.
        hit_count (int): TODO: type description here.
        port_ranges (list of string): TODO: type description here.
        ports (list of string): TODO: type description here.
        protocols (list of string): TODO: type description here.
        valid (bool): TODO: type description here.
        state (int): TODO: type description here.
        usage_percentage (int): TODO: type description here.
        modified_user_id (int): TODO: type description here.
        modified_username (string): TODO: type description here.
        last_modified (string): TODO: type description here.
        timestamp (string): TODO: type description here.
        last_user_modified (string): TODO: type description here.
        state_modified (string): TODO: type description here.
        virtual_zones (VirtualZones): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "actionable_id": 'actionable_id',
        "role_number": 'role_number',
        "role_name": 'role_name',
        "resource_id": 'resource_id',
        "id": 'id',
        "site_id": 'site_id',
        "action": 'action',
        "active": 'active',
        "approved_user_id": 'approved_user_id',
        "approved_username": 'approved_username',
        "categories": 'categories',
        "categories_access": 'categories_access',
        "cloud_reputation": 'cloud_reputation',
        "created_user_id": 'created_user_id',
        "created_username": 'created_username',
        "description": 'description',
        "full_match": 'full_match',
        "hit_count": 'hit_count',
        "port_ranges": 'port_ranges',
        "ports": 'ports',
        "protocols": 'protocols',
        "valid": 'valid',
        "state": 'state',
        "usage_percentage": 'usage_percentage',
        "modified_user_id": 'modified_user_id',
        "modified_username": 'modified_username',
        "last_modified": 'last_modified',
        "timestamp": 'timestamp',
        "last_user_modified": 'last_user_modified',
        "state_modified": 'state_modified',
        "virtual_zones": 'virtual_zones'
    }

    _optionals = [
        'actionable_id',
        'role_number',
        'role_name',
        'resource_id',
        'id',
        'site_id',
        'action',
        'active',
        'approved_user_id',
        'approved_username',
        'categories',
        'categories_access',
        'cloud_reputation',
        'created_user_id',
        'created_username',
        'description',
        'full_match',
        'hit_count',
        'port_ranges',
        'ports',
        'protocols',
        'valid',
        'state',
        'usage_percentage',
        'modified_user_id',
        'modified_username',
        'last_modified',
        'timestamp',
        'last_user_modified',
        'state_modified',
        'virtual_zones',
    ]

    def __init__(self,
                 actionable_id=APIHelper.SKIP,
                 role_number=APIHelper.SKIP,
                 role_name=APIHelper.SKIP,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 action=APIHelper.SKIP,
                 active=APIHelper.SKIP,
                 approved_user_id=APIHelper.SKIP,
                 approved_username=APIHelper.SKIP,
                 categories=APIHelper.SKIP,
                 categories_access=APIHelper.SKIP,
                 cloud_reputation=APIHelper.SKIP,
                 created_user_id=APIHelper.SKIP,
                 created_username=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 full_match=APIHelper.SKIP,
                 hit_count=APIHelper.SKIP,
                 port_ranges=APIHelper.SKIP,
                 ports=APIHelper.SKIP,
                 protocols=APIHelper.SKIP,
                 valid=APIHelper.SKIP,
                 state=APIHelper.SKIP,
                 usage_percentage=APIHelper.SKIP,
                 modified_user_id=APIHelper.SKIP,
                 modified_username=APIHelper.SKIP,
                 last_modified=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 last_user_modified=APIHelper.SKIP,
                 state_modified=APIHelper.SKIP,
                 virtual_zones=APIHelper.SKIP):
        """Constructor for the ActionablePolicy class"""

        # Initialize members of the class
        if actionable_id is not APIHelper.SKIP:
            self.actionable_id = actionable_id 
        if role_number is not APIHelper.SKIP:
            self.role_number = role_number 
        if role_name is not APIHelper.SKIP:
            self.role_name = role_name 
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if action is not APIHelper.SKIP:
            self.action = action 
        if active is not APIHelper.SKIP:
            self.active = active 
        if approved_user_id is not APIHelper.SKIP:
            self.approved_user_id = approved_user_id 
        if approved_username is not APIHelper.SKIP:
            self.approved_username = approved_username 
        if categories is not APIHelper.SKIP:
            self.categories = categories 
        if categories_access is not APIHelper.SKIP:
            self.categories_access = categories_access 
        if cloud_reputation is not APIHelper.SKIP:
            self.cloud_reputation = cloud_reputation 
        if created_user_id is not APIHelper.SKIP:
            self.created_user_id = created_user_id 
        if created_username is not APIHelper.SKIP:
            self.created_username = created_username 
        if description is not APIHelper.SKIP:
            self.description = description 
        if full_match is not APIHelper.SKIP:
            self.full_match = full_match 
        if hit_count is not APIHelper.SKIP:
            self.hit_count = hit_count 
        if port_ranges is not APIHelper.SKIP:
            self.port_ranges = port_ranges 
        if ports is not APIHelper.SKIP:
            self.ports = ports 
        if protocols is not APIHelper.SKIP:
            self.protocols = protocols 
        if valid is not APIHelper.SKIP:
            self.valid = valid 
        if state is not APIHelper.SKIP:
            self.state = state 
        if usage_percentage is not APIHelper.SKIP:
            self.usage_percentage = usage_percentage 
        if modified_user_id is not APIHelper.SKIP:
            self.modified_user_id = modified_user_id 
        if modified_username is not APIHelper.SKIP:
            self.modified_username = modified_username 
        if last_modified is not APIHelper.SKIP:
            self.last_modified = last_modified 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 
        if last_user_modified is not APIHelper.SKIP:
            self.last_user_modified = last_user_modified 
        if state_modified is not APIHelper.SKIP:
            self.state_modified = state_modified 
        if virtual_zones is not APIHelper.SKIP:
            self.virtual_zones = virtual_zones 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        actionable_id = dictionary.get("actionable_id") if dictionary.get("actionable_id") else APIHelper.SKIP
        role_number = dictionary.get("role_number") if dictionary.get("role_number") else APIHelper.SKIP
        role_name = dictionary.get("role_name") if dictionary.get("role_name") else APIHelper.SKIP
        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        action = dictionary.get("action") if dictionary.get("action") else APIHelper.SKIP
        active = dictionary.get("active") if "active" in dictionary.keys() else APIHelper.SKIP
        approved_user_id = dictionary.get("approved_user_id") if dictionary.get("approved_user_id") else APIHelper.SKIP
        approved_username = dictionary.get("approved_username") if dictionary.get("approved_username") else APIHelper.SKIP
        categories = dictionary.get("categories") if dictionary.get("categories") else APIHelper.SKIP
        categories_access = dictionary.get("categories_access") if dictionary.get("categories_access") else APIHelper.SKIP
        cloud_reputation = dictionary.get("cloud_reputation") if dictionary.get("cloud_reputation") else APIHelper.SKIP
        created_user_id = dictionary.get("created_user_id") if dictionary.get("created_user_id") else APIHelper.SKIP
        created_username = dictionary.get("created_username") if dictionary.get("created_username") else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        full_match = dictionary.get("full_match") if "full_match" in dictionary.keys() else APIHelper.SKIP
        hit_count = dictionary.get("hit_count") if dictionary.get("hit_count") else APIHelper.SKIP
        port_ranges = dictionary.get("port_ranges") if dictionary.get("port_ranges") else APIHelper.SKIP
        ports = dictionary.get("ports") if dictionary.get("ports") else APIHelper.SKIP
        protocols = dictionary.get("protocols") if dictionary.get("protocols") else APIHelper.SKIP
        valid = dictionary.get("valid") if "valid" in dictionary.keys() else APIHelper.SKIP
        state = dictionary.get("state") if dictionary.get("state") else APIHelper.SKIP
        usage_percentage = dictionary.get("usage_percentage") if dictionary.get("usage_percentage") else APIHelper.SKIP
        modified_user_id = dictionary.get("modified_user_id") if dictionary.get("modified_user_id") else APIHelper.SKIP
        modified_username = dictionary.get("modified_username") if dictionary.get("modified_username") else APIHelper.SKIP
        last_modified = dictionary.get("last_modified") if dictionary.get("last_modified") else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        last_user_modified = dictionary.get("last_user_modified") if dictionary.get("last_user_modified") else APIHelper.SKIP
        state_modified = dictionary.get("state_modified") if dictionary.get("state_modified") else APIHelper.SKIP
        virtual_zones = VirtualZones.from_dictionary(dictionary.get('virtual_zones')) if 'virtual_zones' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(actionable_id,
                   role_number,
                   role_name,
                   resource_id,
                   id,
                   site_id,
                   action,
                   active,
                   approved_user_id,
                   approved_username,
                   categories,
                   categories_access,
                   cloud_reputation,
                   created_user_id,
                   created_username,
                   description,
                   full_match,
                   hit_count,
                   port_ranges,
                   ports,
                   protocols,
                   valid,
                   state,
                   usage_percentage,
                   modified_user_id,
                   modified_username,
                   last_modified,
                   timestamp,
                   last_user_modified,
                   state_modified,
                   virtual_zones)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort3Enum(object):

    """Implementation of the 'sort3' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAME: TODO: type description here.
        NAME: TODO: type description here.
        ENUM_TRAINING_MODE: TODO: type description here.
        TRAINING_MODE: TODO: type description here.
        ENUM_VERSION: TODO: type description here.
        VERSION: TODO: type description here.
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.
        ENUM_LOCATION_LATITUDE: TODO: type description here.
        LOCATION_LATITUDE: TODO: type description here.
        ENUM_LOCATION_LONGITUDE: TODO: type description here.
        LOCATION_LONGITUDE: TODO: type description here.
        ENUM_DESCRIPTION: TODO: type description here.
        DESCRIPTION: TODO: type description here.
        ENUM_SCORE: TODO: type description here.
        SCORE: TODO: type description here.

    """

    ENUM_NAME = '-name'

    NAME = 'name'

    ENUM_TRAINING_MODE = '-training_mode'

    TRAINING_MODE = 'training_mode'

    ENUM_VERSION = '-version'

    VERSION = 'version'

    ENUM_ID = '-id'

    ID = 'id'

    ENUM_LOCATION_LATITUDE = '-location_latitude'

    LOCATION_LATITUDE = 'location_latitude'

    ENUM_LOCATION_LONGITUDE = '-location_longitude'

    LOCATION_LONGITUDE = 'location_longitude'

    ENUM_DESCRIPTION = '-description'

    DESCRIPTION = 'description'

    ENUM_SCORE = '-score'

    SCORE = 'score'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ContentTypeEnum(object):

    """Implementation of the 'Content-Type' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_APPLICATIONJSON: TODO: type description here.

    """

    ENUM_APPLICATIONJSON = 'application/json'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.code_sections import CodeSections
from ctddocumentation.models.network import Network
from ctddocumentation.models.object import Object


class Asset(object):

    """Implementation of the 'Asset' model.

    TODO: type model description here.

    Attributes:
        resource_id (string): TODO: type description here.
        id (int): TODO: type description here.
        site_id (int): TODO: type description here.
        approved (bool): TODO: type description here.
        asset_type_number (int): TODO: type description here.
        asset_type_name (string): TODO: type description here.
        class_type (string): TODO: type description here.
        criticality_number (int): TODO: type description here.
        criticality_name (string): TODO: type description here.
        display_name (string): TODO: type description here.
        first_seen (string): TODO: type description here.
        last_seen (string): TODO: type description here.
        last_updated (string): TODO: type description here.
        ghost (bool): TODO: type description here.
        hostname (string): TODO: type description here.
        installed_programs_count (int): TODO: type description here.
        mac (list of string): TODO: type description here.
        name (string): TODO: type description here.
        network_id (int): TODO: type description here.
        num_alerts (int): TODO: type description here.
        patch_count (int): TODO: type description here.
        parsed (bool): TODO: type description here.
        protocol (list of string): TODO: type description here.
        purdue_level (float): TODO: type description here.
        risk_level (int): TODO: type description here.
        site_name (string): TODO: type description here.
        special_hint (int): TODO: type description here.
        special_hint_name (string): TODO: type description here.
        vlan (list of string): TODO: type description here.
        virtual_zone_id (int): TODO: type description here.
        virtual_zone_name (string): TODO: type description here.
        vendor (string): TODO: type description here.
        valid (bool): TODO: type description here.
        subnet_id (int): TODO: type description here.
        usb_devices_count (int): TODO: type description here.
        timestamp (string): TODO: type description here.
        network (Network): TODO: type description here.
        active_queries_names (list of string): TODO: type description here.
        active_scans_names (list of string): TODO: type description here.
        children (list of object): TODO: type description here.
        custom_attributes (list of object): TODO: type description here.
        custom_informations (list of object): TODO: type description here.
        insight_names (list of string): TODO: type description here.
        code_sections (list of CodeSections): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_id": 'resource_id',
        "id": 'id',
        "site_id": 'site_id',
        "approved": 'approved',
        "asset_type_number": 'asset_type_number',
        "asset_type_name": 'asset_type_name',
        "class_type": 'class_type',
        "criticality_number": 'criticality_number',
        "criticality_name": 'criticality_name',
        "display_name": 'display_name',
        "first_seen": 'first_seen',
        "last_seen": 'last_seen',
        "last_updated": 'last_updated',
        "ghost": 'ghost',
        "hostname": 'hostname',
        "installed_programs_count": 'installed_programs_count',
        "mac": 'mac',
        "name": 'name',
        "network_id": 'network_id',
        "num_alerts": 'num_alerts',
        "patch_count": 'patch_count',
        "parsed": 'parsed',
        "protocol": 'protocol',
        "purdue_level": 'purdue_level',
        "risk_level": 'risk_level',
        "site_name": 'site_name',
        "special_hint": 'special_hint_',
        "special_hint_name": 'special_hint_name',
        "vlan": 'vlan',
        "virtual_zone_id": 'virtual_zone_id',
        "virtual_zone_name": 'virtual_zone_name',
        "vendor": 'vendor',
        "valid": 'valid',
        "subnet_id": 'subnet_id',
        "usb_devices_count": 'usb_devices_count',
        "timestamp": 'timestamp',
        "network": 'network',
        "active_queries_names": 'active_queries_names',
        "active_scans_names": 'active_scans_names',
        "children": 'children',
        "custom_attributes": 'custom_attributes',
        "custom_informations": 'custom_informations',
        "insight_names": 'insight_names',
        "code_sections": 'code_sections'
    }

    _optionals = [
        'resource_id',
        'id',
        'site_id',
        'approved',
        'asset_type_number',
        'asset_type_name',
        'class_type',
        'criticality_number',
        'criticality_name',
        'display_name',
        'first_seen',
        'last_seen',
        'last_updated',
        'ghost',
        'hostname',
        'installed_programs_count',
        'mac',
        'name',
        'network_id',
        'num_alerts',
        'patch_count',
        'parsed',
        'protocol',
        'purdue_level',
        'risk_level',
        'site_name',
        'special_hint',
        'special_hint_name',
        'vlan',
        'virtual_zone_id',
        'virtual_zone_name',
        'vendor',
        'valid',
        'subnet_id',
        'usb_devices_count',
        'timestamp',
        'network',
        'active_queries_names',
        'active_scans_names',
        'children',
        'custom_attributes',
        'custom_informations',
        'insight_names',
        'code_sections',
    ]

    def __init__(self,
                 resource_id=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 approved=APIHelper.SKIP,
                 asset_type_number=APIHelper.SKIP,
                 asset_type_name=APIHelper.SKIP,
                 class_type=APIHelper.SKIP,
                 criticality_number=APIHelper.SKIP,
                 criticality_name=APIHelper.SKIP,
                 display_name=APIHelper.SKIP,
                 first_seen=APIHelper.SKIP,
                 last_seen=APIHelper.SKIP,
                 last_updated=APIHelper.SKIP,
                 ghost=APIHelper.SKIP,
                 hostname=APIHelper.SKIP,
                 installed_programs_count=APIHelper.SKIP,
                 mac=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 network_id=APIHelper.SKIP,
                 num_alerts=APIHelper.SKIP,
                 patch_count=APIHelper.SKIP,
                 parsed=APIHelper.SKIP,
                 protocol=APIHelper.SKIP,
                 purdue_level=3,
                 risk_level=APIHelper.SKIP,
                 site_name=APIHelper.SKIP,
                 special_hint=APIHelper.SKIP,
                 special_hint_name=APIHelper.SKIP,
                 vlan=APIHelper.SKIP,
                 virtual_zone_id=APIHelper.SKIP,
                 virtual_zone_name=APIHelper.SKIP,
                 vendor=APIHelper.SKIP,
                 valid=APIHelper.SKIP,
                 subnet_id=APIHelper.SKIP,
                 usb_devices_count=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 network=APIHelper.SKIP,
                 active_queries_names=APIHelper.SKIP,
                 active_scans_names=APIHelper.SKIP,
                 children=APIHelper.SKIP,
                 custom_attributes=APIHelper.SKIP,
                 custom_informations=APIHelper.SKIP,
                 insight_names=APIHelper.SKIP,
                 code_sections=APIHelper.SKIP):
        """Constructor for the Asset class"""

        # Initialize members of the class
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if id is not APIHelper.SKIP:
            self.id = id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if approved is not APIHelper.SKIP:
            self.approved = approved 
        if asset_type_number is not APIHelper.SKIP:
            self.asset_type_number = asset_type_number 
        if asset_type_name is not APIHelper.SKIP:
            self.asset_type_name = asset_type_name 
        if class_type is not APIHelper.SKIP:
            self.class_type = class_type 
        if criticality_number is not APIHelper.SKIP:
            self.criticality_number = criticality_number 
        if criticality_name is not APIHelper.SKIP:
            self.criticality_name = criticality_name 
        if display_name is not APIHelper.SKIP:
            self.display_name = display_name 
        if first_seen is not APIHelper.SKIP:
            self.first_seen = first_seen 
        if last_seen is not APIHelper.SKIP:
            self.last_seen = last_seen 
        if last_updated is not APIHelper.SKIP:
            self.last_updated = last_updated 
        if ghost is not APIHelper.SKIP:
            self.ghost = ghost 
        if hostname is not APIHelper.SKIP:
            self.hostname = hostname 
        if installed_programs_count is not APIHelper.SKIP:
            self.installed_programs_count = installed_programs_count 
        if mac is not APIHelper.SKIP:
            self.mac = mac 
        if name is not APIHelper.SKIP:
            self.name = name 
        if network_id is not APIHelper.SKIP:
            self.network_id = network_id 
        if num_alerts is not APIHelper.SKIP:
            self.num_alerts = num_alerts 
        if patch_count is not APIHelper.SKIP:
            self.patch_count = patch_count 
        if parsed is not APIHelper.SKIP:
            self.parsed = parsed 
        if protocol is not APIHelper.SKIP:
            self.protocol = protocol 
        self.purdue_level = purdue_level 
        if risk_level is not APIHelper.SKIP:
            self.risk_level = risk_level 
        if site_name is not APIHelper.SKIP:
            self.site_name = site_name 
        if special_hint is not APIHelper.SKIP:
            self.special_hint = special_hint 
        if special_hint_name is not APIHelper.SKIP:
            self.special_hint_name = special_hint_name 
        if vlan is not APIHelper.SKIP:
            self.vlan = vlan 
        if virtual_zone_id is not APIHelper.SKIP:
            self.virtual_zone_id = virtual_zone_id 
        if virtual_zone_name is not APIHelper.SKIP:
            self.virtual_zone_name = virtual_zone_name 
        if vendor is not APIHelper.SKIP:
            self.vendor = vendor 
        if valid is not APIHelper.SKIP:
            self.valid = valid 
        if subnet_id is not APIHelper.SKIP:
            self.subnet_id = subnet_id 
        if usb_devices_count is not APIHelper.SKIP:
            self.usb_devices_count = usb_devices_count 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 
        if network is not APIHelper.SKIP:
            self.network = network 
        if active_queries_names is not APIHelper.SKIP:
            self.active_queries_names = active_queries_names 
        if active_scans_names is not APIHelper.SKIP:
            self.active_scans_names = active_scans_names 
        if children is not APIHelper.SKIP:
            self.children = children 
        if custom_attributes is not APIHelper.SKIP:
            self.custom_attributes = custom_attributes 
        if custom_informations is not APIHelper.SKIP:
            self.custom_informations = custom_informations 
        if insight_names is not APIHelper.SKIP:
            self.insight_names = insight_names 
        if code_sections is not APIHelper.SKIP:
            self.code_sections = code_sections 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        approved = dictionary.get("approved") if "approved" in dictionary.keys() else APIHelper.SKIP
        asset_type_number = dictionary.get("asset_type_number") if dictionary.get("asset_type_number") else APIHelper.SKIP
        asset_type_name = dictionary.get("asset_type_name") if dictionary.get("asset_type_name") else APIHelper.SKIP
        class_type = dictionary.get("class_type") if dictionary.get("class_type") else APIHelper.SKIP
        criticality_number = dictionary.get("criticality_number") if dictionary.get("criticality_number") else APIHelper.SKIP
        criticality_name = dictionary.get("criticality_name") if dictionary.get("criticality_name") else APIHelper.SKIP
        display_name = dictionary.get("display_name") if dictionary.get("display_name") else APIHelper.SKIP
        first_seen = dictionary.get("first_seen") if dictionary.get("first_seen") else APIHelper.SKIP
        last_seen = dictionary.get("last_seen") if dictionary.get("last_seen") else APIHelper.SKIP
        last_updated = dictionary.get("last_updated") if dictionary.get("last_updated") else APIHelper.SKIP
        ghost = dictionary.get("ghost") if "ghost" in dictionary.keys() else APIHelper.SKIP
        hostname = dictionary.get("hostname") if dictionary.get("hostname") else APIHelper.SKIP
        installed_programs_count = dictionary.get("installed_programs_count") if dictionary.get("installed_programs_count") else APIHelper.SKIP
        mac = dictionary.get("mac") if dictionary.get("mac") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        network_id = dictionary.get("network_id") if dictionary.get("network_id") else APIHelper.SKIP
        num_alerts = dictionary.get("num_alerts") if dictionary.get("num_alerts") else APIHelper.SKIP
        patch_count = dictionary.get("patch_count") if dictionary.get("patch_count") else APIHelper.SKIP
        parsed = dictionary.get("parsed") if "parsed" in dictionary.keys() else APIHelper.SKIP
        protocol = dictionary.get("protocol") if dictionary.get("protocol") else APIHelper.SKIP
        purdue_level = dictionary.get("purdue_level") if dictionary.get("purdue_level") else 3
        risk_level = dictionary.get("risk_level") if dictionary.get("risk_level") else APIHelper.SKIP
        site_name = dictionary.get("site_name") if dictionary.get("site_name") else APIHelper.SKIP
        special_hint = dictionary.get("special_hint_") if dictionary.get("special_hint_") else APIHelper.SKIP
        special_hint_name = dictionary.get("special_hint_name") if dictionary.get("special_hint_name") else APIHelper.SKIP
        vlan = dictionary.get("vlan") if dictionary.get("vlan") else APIHelper.SKIP
        virtual_zone_id = dictionary.get("virtual_zone_id") if dictionary.get("virtual_zone_id") else APIHelper.SKIP
        virtual_zone_name = dictionary.get("virtual_zone_name") if dictionary.get("virtual_zone_name") else APIHelper.SKIP
        vendor = dictionary.get("vendor") if dictionary.get("vendor") else APIHelper.SKIP
        valid = dictionary.get("valid") if "valid" in dictionary.keys() else APIHelper.SKIP
        subnet_id = dictionary.get("subnet_id") if dictionary.get("subnet_id") else APIHelper.SKIP
        usb_devices_count = dictionary.get("usb_devices_count") if dictionary.get("usb_devices_count") else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        network = Network.from_dictionary(dictionary.get('network')) if 'network' in dictionary.keys() else APIHelper.SKIP
        active_queries_names = dictionary.get("active_queries_names") if dictionary.get("active_queries_names") else APIHelper.SKIP
        active_scans_names = dictionary.get("active_scans_names") if dictionary.get("active_scans_names") else APIHelper.SKIP
        children = None
        if dictionary.get('children') is not None:
            children = [Object.from_dictionary(x) for x in dictionary.get('children')]
        else:
            children = APIHelper.SKIP
        custom_attributes = None
        if dictionary.get('custom_attributes') is not None:
            custom_attributes = [Object.from_dictionary(x) for x in dictionary.get('custom_attributes')]
        else:
            custom_attributes = APIHelper.SKIP
        custom_informations = None
        if dictionary.get('custom_informations') is not None:
            custom_informations = [Object.from_dictionary(x) for x in dictionary.get('custom_informations')]
        else:
            custom_informations = APIHelper.SKIP
        insight_names = dictionary.get("insight_names") if dictionary.get("insight_names") else APIHelper.SKIP
        code_sections = None
        if dictionary.get('code_sections') is not None:
            code_sections = [CodeSections.from_dictionary(x) for x in dictionary.get('code_sections')]
        else:
            code_sections = APIHelper.SKIP
        # Return an object of this model
        return cls(resource_id,
                   id,
                   site_id,
                   approved,
                   asset_type_number,
                   asset_type_name,
                   class_type,
                   criticality_number,
                   criticality_name,
                   display_name,
                   first_seen,
                   last_seen,
                   last_updated,
                   ghost,
                   hostname,
                   installed_programs_count,
                   mac,
                   name,
                   network_id,
                   num_alerts,
                   patch_count,
                   parsed,
                   protocol,
                   purdue_level,
                   risk_level,
                   site_name,
                   special_hint,
                   special_hint_name,
                   vlan,
                   virtual_zone_id,
                   virtual_zone_name,
                   vendor,
                   valid,
                   subnet_id,
                   usb_devices_count,
                   timestamp,
                   network,
                   active_queries_names,
                   active_scans_names,
                   children,
                   custom_attributes,
                   custom_informations,
                   insight_names,
                   code_sections)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SortEnum(object):

    """Implementation of the 'sort' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_SITE: TODO: type description here.
        SITE: TODO: type description here.
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.
        ENUM_SITE_ID: TODO: type description here.
        SITE_ID: TODO: type description here.
        ENUM_DATA: TODO: type description here.
        DATA: TODO: type description here.
        ENUM_DESCRIPTION: TODO: type description here.
        DESCRIPTION: TODO: type description here.
        ENUM_TYPE: TODO: type description here.
        TYPE: TODO: type description here.
        ENUM_CATEGORY: TODO: type description here.
        CATEGORY: TODO: type description here.
        ENUM_SEVERITY: TODO: type description here.
        SEVERITY: TODO: type description here.
        ENUM_TIMESTAMP: TODO: type description here.
        TIMESTAMP: TODO: type description here.
        ENUM_RELEVANT: TODO: type description here.
        RELEVANT: TODO: type description here.
        ENUM_RESOLVED: TODO: type description here.
        RESOLVED: TODO: type description here.
        ENUM_RESOLUTION: TODO: type description here.
        RESOLUTION: TODO: type description here.
        ENUM_PROTOCOL: TODO: type description here.
        PROTOCOL: TODO: type description here.
        ENUM_SCORE: TODO: type description here.
        SCORE: TODO: type description here.
        ENUM_IS_QUALIFIED: TODO: type description here.
        IS_QUALIFIED: TODO: type description here.
        ENUM_NETWORK_ID: TODO: type description here.
        NETWORK_ID: TODO: type description here.
        ENUM_RESOLVED_ID: TODO: type description here.
        RESOLVED_ID: TODO: type description here.
        ENUM_ASSIGNED_ID: TODO: type description here.
        ASSIGNED_ID: TODO: type description here.
        ENUM_STORY_ID: TODO: type description here.
        STORY_ID: TODO: type description here.

    """

    ENUM_SITE = '-site'

    SITE = 'site'

    ENUM_ID = '-id'

    ID = 'id'

    ENUM_SITE_ID = '-site_id'

    SITE_ID = 'site_id'

    ENUM_DATA = '-data'

    DATA = 'data'

    ENUM_DESCRIPTION = '-description'

    DESCRIPTION = 'description'

    ENUM_TYPE = '-type'

    ENUM_TYPE = 'type'

    ENUM_CATEGORY = '-category'

    CATEGORY = 'category'

    ENUM_SEVERITY = '-severity'

    SEVERITY = 'severity'

    ENUM_TIMESTAMP = '-timestamp'

    TIMESTAMP = 'timestamp'

    ENUM_RELEVANT = '-relevant'

    RELEVANT = 'relevant'

    ENUM_RESOLVED = '-resolved'

    RESOLVED = 'resolved'

    ENUM_RESOLUTION = '-resolution'

    RESOLUTION = 'resolution'

    ENUM_PROTOCOL = '-protocol'

    PROTOCOL = 'protocol'

    ENUM_SCORE = '-score'

    SCORE = 'score'

    ENUM_IS_QUALIFIED = '-is_qualified'

    IS_QUALIFIED = 'is_qualified'

    ENUM_NETWORK_ID = '-network_id'

    NETWORK_ID = 'network_id'

    ENUM_RESOLVED_ID = '-resolved_id'

    RESOLVED_ID = 'resolved_id'

    ENUM_ASSIGNED_ID = '-assigned_id'

    ASSIGNED_ID = 'assigned_id'

    ENUM_STORY_ID = '-story_id'

    STORY_ID = 'story_id'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class CTDLoginException(object):

    """Implementation of the 'CTDLoginException' model.

    TODO: type model description here.

    Attributes:
        error (string): TODO: type description here.
        exception (string): TODO: type description here.
        exception_class (string): TODO: type description here.
        success (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "error": 'error',
        "exception": 'exception',
        "exception_class": 'exception_class',
        "success": 'success'
    }

    _optionals = [
        'error',
        'exception',
        'exception_class',
        'success',
    ]

    def __init__(self,
                 error=APIHelper.SKIP,
                 exception=APIHelper.SKIP,
                 exception_class=APIHelper.SKIP,
                 success=APIHelper.SKIP):
        """Constructor for the CTDLoginException class"""

        # Initialize members of the class
        if error is not APIHelper.SKIP:
            self.error = error 
        if exception is not APIHelper.SKIP:
            self.exception = exception 
        if exception_class is not APIHelper.SKIP:
            self.exception_class = exception_class 
        if success is not APIHelper.SKIP:
            self.success = success 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        error = dictionary.get("error") if dictionary.get("error") else APIHelper.SKIP
        exception = dictionary.get("exception") if dictionary.get("exception") else APIHelper.SKIP
        exception_class = dictionary.get("exception_class") if dictionary.get("exception_class") else APIHelper.SKIP
        success = dictionary.get("success") if "success" in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(error,
                   exception,
                   exception_class,
                   success)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class CodeSections(object):

    """Implementation of the 'CodeSections' model.

    TODO: type model description here.

    Attributes:
        mtype (string): TODO: type description here.
        filename (string): TODO: type description here.
        rid (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype": 'type',
        "filename": 'filename',
        "rid": 'rid'
    }

    _optionals = [
        'mtype',
        'filename',
        'rid',
    ]

    def __init__(self,
                 mtype=APIHelper.SKIP,
                 filename=APIHelper.SKIP,
                 rid=APIHelper.SKIP):
        """Constructor for the CodeSections class"""

        # Initialize members of the class
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if filename is not APIHelper.SKIP:
            self.filename = filename 
        if rid is not APIHelper.SKIP:
            self.rid = rid 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        filename = dictionary.get("filename") if dictionary.get("filename") else APIHelper.SKIP
        rid = dictionary.get("rid") if dictionary.get("rid") else APIHelper.SKIP
        # Return an object of this model
        return cls(mtype,
                   filename,
                   rid)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.indicator_info import IndicatorInfo


class Indicators(object):

    """Implementation of the 'Indicators' model.

    TODO: type model description here.

    Attributes:
        id (int): TODO: type description here.
        alert_id (int): TODO: type description here.
        indicator_id (int): TODO: type description here.
        indicator_result (bool): TODO: type description here.
        parent_indicator_id (int): TODO: type description here.
        site_id (int): TODO: type description here.
        indicator_info (IndicatorInfo): TODO: type description here.
        icon (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "alert_id": 'alert_id',
        "indicator_id": 'indicator_id',
        "indicator_result": 'indicator_result',
        "parent_indicator_id": 'parent_indicator_id',
        "site_id": 'site_id',
        "indicator_info": 'indicator_info',
        "icon": 'icon'
    }

    _optionals = [
        'id',
        'alert_id',
        'indicator_id',
        'indicator_result',
        'parent_indicator_id',
        'site_id',
        'indicator_info',
        'icon',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 alert_id=APIHelper.SKIP,
                 indicator_id=APIHelper.SKIP,
                 indicator_result=APIHelper.SKIP,
                 parent_indicator_id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 indicator_info=APIHelper.SKIP,
                 icon=APIHelper.SKIP):
        """Constructor for the Indicators class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if alert_id is not APIHelper.SKIP:
            self.alert_id = alert_id 
        if indicator_id is not APIHelper.SKIP:
            self.indicator_id = indicator_id 
        if indicator_result is not APIHelper.SKIP:
            self.indicator_result = indicator_result 
        if parent_indicator_id is not APIHelper.SKIP:
            self.parent_indicator_id = parent_indicator_id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if indicator_info is not APIHelper.SKIP:
            self.indicator_info = indicator_info 
        if icon is not APIHelper.SKIP:
            self.icon = icon 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        alert_id = dictionary.get("alert_id") if dictionary.get("alert_id") else APIHelper.SKIP
        indicator_id = dictionary.get("indicator_id") if dictionary.get("indicator_id") else APIHelper.SKIP
        indicator_result = dictionary.get("indicator_result") if "indicator_result" in dictionary.keys() else APIHelper.SKIP
        parent_indicator_id = dictionary.get("parent_indicator_id") if dictionary.get("parent_indicator_id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        indicator_info = IndicatorInfo.from_dictionary(dictionary.get('indicator_info')) if 'indicator_info' in dictionary.keys() else APIHelper.SKIP
        icon = dictionary.get("icon") if dictionary.get("icon") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   alert_id,
                   indicator_id,
                   indicator_result,
                   parent_indicator_id,
                   site_id,
                   indicator_info,
                   icon)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusEnum(object):

    """Implementation of the 'Status' enum.

    TODO: type enum description here.

    Attributes:
        GREEN: TODO: type description here.
        RED: TODO: type description here.

    """

    GREEN = 'green'

    RED = 'red'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort4Enum(object):

    """Implementation of the 'sort4' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.
        ENUM_SITE_ID: TODO: type description here.
        SITE_ID: TODO: type description here.
        ENUM_TYPE: TODO: type description here.
        TYPE: TODO: type description here.
        ENUM_TIMESTAMP: TODO: type description here.
        TIMESTAMP: TODO: type description here.
        ENUM_USER_ID: TODO: type description here.
        USER_ID: TODO: type description here.

    """

    ENUM_ID = '-id'

    ID = 'id'

    ENUM_SITE_ID = '-site_id'

    SITE_ID = 'site_id'

    ENUM_TYPE = '-type'

    ENUM_TYPE = 'type'

    ENUM_TIMESTAMP = '-timestamp'

    TIMESTAMP = 'timestamp'

    ENUM_USER_ID = '-user_id'

    USER_ID = 'user_id'



__all__ = [
    'base_controller',
    'login_controller',
    'assets_controller',
    'alerts_controller',
    'tasks_controller',
    'tasks_queries_controller',
    'queries_controller',
    'insights_controller',
    'sites_controller',
    'activities_controller',
    'license_controller',
    'users_controller',
    'groups_controller',
    'sensors_controller',
    'custom_attributes_categories_controller',
    'events_controller',
]



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CreateUserResponse(object):

    """Implementation of the 'CreateUserResponse' model.

    TODO: type model description here.

    Attributes:
        user_id (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_id": 'user_id'
    }

    def __init__(self,
                 user_id=None):
        """Constructor for the CreateUserResponse class"""

        # Initialize members of the class
        self.user_id = user_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        user_id = dictionary.get("user_id") if dictionary.get("user_id") else None
        # Return an object of this model
        return cls(user_id)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AlertSeverityEnum(object):

    """Implementation of the 'AlertSeverity' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAMELOWVALUE0: TODO: type description here.
        ENUM_NAMEMEDIUMVALUE1: TODO: type description here.
        ENUM_NAMEHIGHVALUE2: TODO: type description here.
        ENUM_NAMECRITICALVALUE3: TODO: type description here.

    """

    ENUM_NAMELOWVALUE0 = '{"name":"Low","value":0}'

    ENUM_NAMEMEDIUMVALUE1 = '{"name":"Medium","value":1}'

    ENUM_NAMEHIGHVALUE2 = '{"name":"High","value":2}'

    ENUM_NAMECRITICALVALUE3 = '{"name":"Critical","value":3}'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class InsightStatusEnum(object):

    """Implementation of the 'InsightStatus' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAMEOPENVALUE0: TODO: type description here.
        ENUM_NAMEHIDDENVALUE1: TODO: type description here.
        ENUM_NAMECOMPLETEDVALUE2: TODO: type description here.

    """

    ENUM_NAMEOPENVALUE0 = '{"name":"Open","value":0}'

    ENUM_NAMEHIDDENVALUE1 = '{"name":"Hidden","value":1}'

    ENUM_NAMECOMPLETEDVALUE2 = '{"name":"Completed","value":2}'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CreateanewtaskResponse(object):

    """Implementation of the 'CreateanewtaskResponse' model.

    TODO: type model description here.

    Attributes:
        success (bool): TODO: type description here.
        data (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "success": 'success',
        "data": 'data'
    }

    def __init__(self,
                 success=None,
                 data=None):
        """Constructor for the CreateanewtaskResponse class"""

        # Initialize members of the class
        self.success = success 
        self.data = data 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        success = dictionary.get("success") if "success" in dictionary.keys() else None
        data = dictionary.get("data") if dictionary.get("data") else None
        # Return an object of this model
        return cls(success,
                   data)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.queryextraparams import Queryextraparams


class NewQueryobject(object):

    """Implementation of the 'NewQueryobject' model.

    TODO: type model description here.

    Attributes:
        allowed_days (string): A string that represents specific days in a
            week, Sunday being 0 and Friday being 6. To select more than a
            specific day just concatenate the day number to the string
        allowed_run_time_end (string): TODO: type description here.
        allowed_run_time_start (string): TODO: type description here.
        end_time (string): TODO: type description here.
        start_time (string): TODO: type description here.
        attached_queries (list of int): TODO: type description here.
        enabled (bool): TODO: type description here.
        interval (string): TODO: type description here.
        is_recurring (bool): TODO: type description here.
        name (string): TODO: type description here.
        network_id (int): TODO: type description here.
        mtype (int): TODO: type description here.
        extra_params (Queryextraparams): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "allowed_days": 'allowed_days',
        "allowed_run_time_end": 'allowed_run_time_end',
        "allowed_run_time_start": 'allowed_run_time_start',
        "end_time": 'end_time',
        "start_time": 'start_time',
        "attached_queries": 'attached_queries',
        "enabled": 'enabled',
        "interval": 'interval',
        "is_recurring": 'is_recurring',
        "name": 'name',
        "network_id": 'network_id',
        "mtype": 'type',
        "extra_params": 'extra_params'
    }

    _optionals = [
        'allowed_days',
        'allowed_run_time_end',
        'allowed_run_time_start',
        'end_time',
        'start_time',
        'attached_queries',
        'enabled',
        'interval',
        'is_recurring',
        'name',
        'network_id',
        'mtype',
        'extra_params',
    ]

    def __init__(self,
                 allowed_days=APIHelper.SKIP,
                 allowed_run_time_end=APIHelper.SKIP,
                 allowed_run_time_start=APIHelper.SKIP,
                 end_time=APIHelper.SKIP,
                 start_time=APIHelper.SKIP,
                 attached_queries=APIHelper.SKIP,
                 enabled=APIHelper.SKIP,
                 interval=APIHelper.SKIP,
                 is_recurring=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 network_id=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 extra_params=APIHelper.SKIP):
        """Constructor for the NewQueryobject class"""

        # Initialize members of the class
        if allowed_days is not APIHelper.SKIP:
            self.allowed_days = allowed_days 
        if allowed_run_time_end is not APIHelper.SKIP:
            self.allowed_run_time_end = allowed_run_time_end 
        if allowed_run_time_start is not APIHelper.SKIP:
            self.allowed_run_time_start = allowed_run_time_start 
        if end_time is not APIHelper.SKIP:
            self.end_time = end_time 
        if start_time is not APIHelper.SKIP:
            self.start_time = start_time 
        if attached_queries is not APIHelper.SKIP:
            self.attached_queries = attached_queries 
        if enabled is not APIHelper.SKIP:
            self.enabled = enabled 
        if interval is not APIHelper.SKIP:
            self.interval = interval 
        if is_recurring is not APIHelper.SKIP:
            self.is_recurring = is_recurring 
        if name is not APIHelper.SKIP:
            self.name = name 
        if network_id is not APIHelper.SKIP:
            self.network_id = network_id 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if extra_params is not APIHelper.SKIP:
            self.extra_params = extra_params 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        allowed_days = dictionary.get("allowed_days") if dictionary.get("allowed_days") else APIHelper.SKIP
        allowed_run_time_end = dictionary.get("allowed_run_time_end") if dictionary.get("allowed_run_time_end") else APIHelper.SKIP
        allowed_run_time_start = dictionary.get("allowed_run_time_start") if dictionary.get("allowed_run_time_start") else APIHelper.SKIP
        end_time = dictionary.get("end_time") if dictionary.get("end_time") else APIHelper.SKIP
        start_time = dictionary.get("start_time") if dictionary.get("start_time") else APIHelper.SKIP
        attached_queries = dictionary.get("attached_queries") if dictionary.get("attached_queries") else APIHelper.SKIP
        enabled = dictionary.get("enabled") if "enabled" in dictionary.keys() else APIHelper.SKIP
        interval = dictionary.get("interval") if dictionary.get("interval") else APIHelper.SKIP
        is_recurring = dictionary.get("is_recurring") if "is_recurring" in dictionary.keys() else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        network_id = dictionary.get("network_id") if dictionary.get("network_id") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        extra_params = Queryextraparams.from_dictionary(dictionary.get('extra_params')) if 'extra_params' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(allowed_days,
                   allowed_run_time_end,
                   allowed_run_time_start,
                   end_time,
                   start_time,
                   attached_queries,
                   enabled,
                   interval,
                   is_recurring,
                   name,
                   network_id,
                   mtype,
                   extra_params)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SpecialHintExactEnum(object):

    """Implementation of the 'special_hint__exact' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.

    """

    ENUM_0 = 0

    ENUM_1 = 1

    ENUM_2 = 2

    ENUM_3 = 3

    ENUM_4 = 4



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class CTDLoginResponse(object):

    """Implementation of the 'CTDLoginResponse' model.

    TODO: type model description here.

    Attributes:
        id (int): TODO: type description here.
        first_name (string): TODO: type description here.
        last_name (string): TODO: type description here.
        token (string): TODO: type description here.
        password_expired (bool): TODO: type description here.
        mail (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "first_name": 'first_name',
        "last_name": 'last_name',
        "token": 'token',
        "password_expired": 'password_expired',
        "mail": 'mail'
    }

    _optionals = [
        'id',
        'first_name',
        'last_name',
        'token',
        'password_expired',
        'mail',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 first_name=APIHelper.SKIP,
                 last_name=APIHelper.SKIP,
                 token=APIHelper.SKIP,
                 password_expired=APIHelper.SKIP,
                 mail=APIHelper.SKIP):
        """Constructor for the CTDLoginResponse class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name 
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name 
        if token is not APIHelper.SKIP:
            self.token = token 
        if password_expired is not APIHelper.SKIP:
            self.password_expired = password_expired 
        if mail is not APIHelper.SKIP:
            self.mail = mail 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        first_name = dictionary.get("first_name") if dictionary.get("first_name") else APIHelper.SKIP
        last_name = dictionary.get("last_name") if dictionary.get("last_name") else APIHelper.SKIP
        token = dictionary.get("token") if dictionary.get("token") else APIHelper.SKIP
        password_expired = dictionary.get("password_expired") if "password_expired" in dictionary.keys() else APIHelper.SKIP
        mail = dictionary.get("mail") if dictionary.get("mail") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   first_name,
                   last_name,
                   token,
                   password_expired,
                   mail)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Authenticate(object):

    """Implementation of the 'Authenticate' model.

    TODO: type model description here.

    Attributes:
        username (string): TODO: type description here.
        password (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "username": 'username',
        "password": 'password'
    }

    def __init__(self,
                 username=None,
                 password=None):
        """Constructor for the Authenticate class"""

        # Initialize members of the class
        self.username = username 
        self.password = password 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        username = dictionary.get("username") if dictionary.get("username") else None
        password = dictionary.get("password") if dictionary.get("password") else None
        # Return an object of this model
        return cls(username,
                   password)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class Taskextraparams(object):

    """Implementation of the 'Taskextraparams' model.

    TODO: type model description here.

    Attributes:
        query_discovered_devices (bool): TODO: type description here.
        port (int): TODO: type description here.
        sub_query (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "query_discovered_devices": 'Query_Discovered_Devices',
        "port": 'port',
        "sub_query": 'sub_query'
    }

    _optionals = [
        'query_discovered_devices',
        'port',
        'sub_query',
    ]

    def __init__(self,
                 query_discovered_devices=APIHelper.SKIP,
                 port=APIHelper.SKIP,
                 sub_query=APIHelper.SKIP):
        """Constructor for the Taskextraparams class"""

        # Initialize members of the class
        if query_discovered_devices is not APIHelper.SKIP:
            self.query_discovered_devices = query_discovered_devices 
        if port is not APIHelper.SKIP:
            self.port = port 
        if sub_query is not APIHelper.SKIP:
            self.sub_query = sub_query 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        query_discovered_devices = dictionary.get("Query_Discovered_Devices") if "Query_Discovered_Devices" in dictionary.keys() else APIHelper.SKIP
        port = dictionary.get("port") if dictionary.get("port") else APIHelper.SKIP
        sub_query = dictionary.get("sub_query") if dictionary.get("sub_query") else APIHelper.SKIP
        # Return an object of this model
        return cls(query_discovered_devices,
                   port,
                   sub_query)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or


class InsightsController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(InsightsController, self).__init__(config)

    def get_insights_summary(self,
                             format,
                             sort,
                             content_type,
                             page=1,
                             per_page=50,
                             site_id__exact=1,
                             ghost__exact=False,
                             special_hint__exact=None,
                             insight_status__exact=None):
        """Does a GET request to /ranger/insights_summary.

        In order to retrieve all the assets associated with a specific
        Insight
        Step 1:
        1. Apply the relevant site number in the site_id__exact field
        2. Click "Try It Out"
        3. From the Response body, select the insight of interest,  e.g.
        Assets Accessed SMB shares
        4. Copy the string of the insight name e.g. "Assets Accessed SMB
        shares"
        5. Find further instructions in 'Get Insight Details by Name' API
        endpoint

        Args:
            format (string): TODO: type description here.
            sort (string): TODO: type description here.
            content_type (ContentTypeEnum): TODO: type description here.
            page (int, optional): The actual page offset
            per_page (int, optional): Number of Insights to pull per page
            site_id__exact (int, optional): The identifier of the Site related
                to the Insight
            ghost__exact (bool, optional): Whether or not this is a ghost
                asset: TRUE = Ghost
            special_hint__exact (SpecialHintExactEnum, optional): TODO: type
                description here.
            insight_status__exact (InsightStatusExact1Enum, optional): The
                status of the Insight associated with this Asset – this is a
                dropdown for choosing the integer type:  0 = Open  1 = Hidden 
                2 = Completed

        Returns:
            void: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/insights_summary')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('format')
                         .value(format))
            .query_param(Parameter()
                         .key('sort')
                         .value(sort))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value(content_type))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .query_param(Parameter()
                         .key('ghost__exact')
                         .value(ghost__exact))
            .query_param(Parameter()
                         .key('special_hint__exact')
                         .value(special_hint__exact))
            .query_param(Parameter()
                         .key('insight_status__exact')
                         .value(insight_status__exact))
            .auth(Single('global'))
        ).execute()

    def get_insight_details_by_name(self,
                                    insight_name,
                                    format='insight_page',
                                    page=1,
                                    per_page=10,
                                    site_id__exact=1,
                                    ghost__exact=False,
                                    special_hint__exact=None,
                                    insight_status__exact=None):
        """Does a GET request to /ranger/insight_details/{insight_name}.

        In order to retrieve all the assets associated with a specific
        Insight:
        Step 2 (Step1 is in 'Get Insights Summary' endpoint):
        1. Enter (paste) the insight name from above into the insight_name
        field 
        2. Apply the relevant site number in the site_id__exact field
        3. Click Execute
        4. From the Response Body, Select the FILTER_KEY
        5. Copy the string of the FILTER_KEY 
        6. Find further instructions in /ranger/assets

        Args:
            insight_name (string): TODO: type description here.
            format (string, optional): TODO: type description here. Example:
                insight_page
            page (int, optional): The actual page offset
            per_page (int, optional): Number of Insights to pull per page
            site_id__exact (int, optional): The identifier of the Site related
                to the Insight
            ghost__exact (bool, optional): Whether or not this is a ghost
                asset: TRUE = Ghost
            special_hint__exact (SpecialHintExactEnum, optional): TODO: type
                description here.
            insight_status__exact (InsightStatusExact1Enum, optional): The
                status of the Insight associated with this Asset – this is a
                dropdown for choosing the integer type:  0 = Open  1 = Hidden 
                2 = Completed

        Returns:
            void: Response from the API. Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/insight_details/{insight_name}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('insight_name')
                            .value(insight_name)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('format')
                         .value(format))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .query_param(Parameter()
                         .key('ghost__exact')
                         .value(ghost__exact))
            .query_param(Parameter()
                         .key('special_hint__exact')
                         .value(special_hint__exact))
            .query_param(Parameter()
                         .key('insight_status__exact')
                         .value(insight_status__exact))
            .auth(Single('global'))
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.detail import Detail


class RiskVector(object):

    """Implementation of the 'RiskVector' model.

    TODO: type model description here.

    Attributes:
        details (list of Detail): TODO: type description here.
        name (string): TODO: type description here.
        scale (float): TODO: type description here.
        score (float): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "details": 'details',
        "name": 'name',
        "scale": 'scale',
        "score": 'score'
    }

    _optionals = [
        'details',
        'name',
        'scale',
        'score',
    ]

    def __init__(self,
                 details=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 scale=APIHelper.SKIP,
                 score=APIHelper.SKIP):
        """Constructor for the RiskVector class"""

        # Initialize members of the class
        if details is not APIHelper.SKIP:
            self.details = details 
        if name is not APIHelper.SKIP:
            self.name = name 
        if scale is not APIHelper.SKIP:
            self.scale = scale 
        if score is not APIHelper.SKIP:
            self.score = score 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        details = None
        if dictionary.get('details') is not None:
            details = [Detail.from_dictionary(x) for x in dictionary.get('details')]
        else:
            details = APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        scale = dictionary.get("scale") if dictionary.get("scale") else APIHelper.SKIP
        score = dictionary.get("score") if dictionary.get("score") else APIHelper.SKIP
        # Return an object of this model
        return cls(details,
                   name,
                   scale,
                   score)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusExactEnum(object):

    """Implementation of the 'status__exact' enum.

    TODO: type enum description here.

    Attributes:
        EOTALERT: TODO: type description here.
        EOTOPERATION: TODO: type description here.
        EALERT: TODO: type description here.
        ENOTRISKY: TODO: type description here.

    """

    EOTALERT = 'eOtAlert'

    EOTOPERATION = 'eOtOperation'

    EALERT = 'eAlert'

    ENOTRISKY = 'eNotRisky'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.object import Object


class SelectionParams1(object):

    """Implementation of the 'SelectionParams1' model.

    TODO: type model description here.

    Attributes:
        excluded (list of string): TODO: type description here.
        filters (object): TODO: type description here.
        select_all (bool): TODO: type description here.
        selected (list of string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "excluded": 'excluded',
        "filters": 'filters',
        "select_all": 'select_all',
        "selected": 'selected'
    }

    _optionals = [
        'excluded',
        'filters',
        'select_all',
        'selected',
    ]

    def __init__(self,
                 excluded=APIHelper.SKIP,
                 filters=APIHelper.SKIP,
                 select_all=False,
                 selected=APIHelper.SKIP):
        """Constructor for the SelectionParams1 class"""

        # Initialize members of the class
        if excluded is not APIHelper.SKIP:
            self.excluded = excluded 
        if filters is not APIHelper.SKIP:
            self.filters = filters 
        self.select_all = select_all 
        if selected is not APIHelper.SKIP:
            self.selected = selected 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        excluded = dictionary.get("excluded") if dictionary.get("excluded") else APIHelper.SKIP
        filters = Object.from_dictionary(dictionary.get('filters')) if 'filters' in dictionary.keys() else APIHelper.SKIP
        select_all = dictionary.get("select_all") if dictionary.get("select_all") else False
        selected = dictionary.get("selected") if dictionary.get("selected") else APIHelper.SKIP
        # Return an object of this model
        return cls(excluded,
                   filters,
                   select_all,
                   selected)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class Object(object):

    """Implementation of the 'Object' model.

    TODO: type model description here.

    Attributes:
        description (string): TODO: type description here.
        user_id (string): TODO: type description here.
        resolved (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description": 'description',
        "user_id": 'user_id',
        "resolved": 'resolved'
    }

    _optionals = [
        'description',
        'user_id',
        'resolved',
    ]

    def __init__(self,
                 description=APIHelper.SKIP,
                 user_id=APIHelper.SKIP,
                 resolved=APIHelper.SKIP):
        """Constructor for the Object class"""

        # Initialize members of the class
        if description is not APIHelper.SKIP:
            self.description = description 
        if user_id is not APIHelper.SKIP:
            self.user_id = user_id 
        if resolved is not APIHelper.SKIP:
            self.resolved = resolved 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        user_id = dictionary.get("user_id") if dictionary.get("user_id") else APIHelper.SKIP
        resolved = dictionary.get("resolved") if "resolved" in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(description,
                   user_id,
                   resolved)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.configurations.global_configuration import GlobalConfiguration
from apimatic_core.decorators.lazy_property import LazyProperty
from ctddocumentation.configuration import Configuration
from ctddocumentation.controllers.base_controller import BaseController
from ctddocumentation.configuration import Environment
from ctddocumentation.http.auth.custom_header_authentication import CustomHeaderAuthentication
from ctddocumentation.controllers.login_controller import LoginController
from ctddocumentation.controllers.assets_controller import AssetsController
from ctddocumentation.controllers.alerts_controller import AlertsController
from ctddocumentation.controllers.tasks_controller import TasksController
from ctddocumentation.controllers.tasks_queries_controller\
    import TasksQueriesController
from ctddocumentation.controllers.queries_controller import QueriesController
from ctddocumentation.controllers.insights_controller import InsightsController
from ctddocumentation.controllers.sites_controller import SitesController
from ctddocumentation.controllers.activities_controller\
    import ActivitiesController
from ctddocumentation.controllers.license_controller import LicenseController
from ctddocumentation.controllers.users_controller import UsersController
from ctddocumentation.controllers.groups_controller import GroupsController
from ctddocumentation.controllers.sensors_controller import SensorsController
from ctddocumentation.controllers.custom_attributes_categories_controller\
    import CustomAttributesCategoriesController
from ctddocumentation.controllers.events_controller import EventsController


class CtddocumentationClient(object):

    @LazyProperty
    def login(self):
        return LoginController(self.global_configuration)

    @LazyProperty
    def assets(self):
        return AssetsController(self.global_configuration)

    @LazyProperty
    def alerts(self):
        return AlertsController(self.global_configuration)

    @LazyProperty
    def tasks(self):
        return TasksController(self.global_configuration)

    @LazyProperty
    def tasks_queries(self):
        return TasksQueriesController(self.global_configuration)

    @LazyProperty
    def queries(self):
        return QueriesController(self.global_configuration)

    @LazyProperty
    def insights(self):
        return InsightsController(self.global_configuration)

    @LazyProperty
    def sites(self):
        return SitesController(self.global_configuration)

    @LazyProperty
    def activities(self):
        return ActivitiesController(self.global_configuration)

    @LazyProperty
    def license(self):
        return LicenseController(self.global_configuration)

    @LazyProperty
    def users(self):
        return UsersController(self.global_configuration)

    @LazyProperty
    def groups(self):
        return GroupsController(self.global_configuration)

    @LazyProperty
    def sensors(self):
        return SensorsController(self.global_configuration)

    @LazyProperty
    def custom_attributes_categories(self):
        return CustomAttributesCategoriesController(self.global_configuration)

    @LazyProperty
    def events(self):
        return EventsController(self.global_configuration)

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=[408, 413, 429, 500, 502, 503, 504, 521, 522, 524],
                 retry_methods=['GET', 'PUT'],
                 environment=Environment.PRODUCTION, host='HostValue',
                 authorization='TODO: Replace', config=None):
        if config is None:
            self.config = Configuration(
                                         http_client_instance=http_client_instance,
                                         override_http_client_configuration=override_http_client_configuration,
                                         http_call_back=http_call_back,
                                         timeout=timeout,
                                         max_retries=max_retries,
                                         backoff_factor=backoff_factor,
                                         retry_statuses=retry_statuses,
                                         retry_methods=retry_methods,
                                         environment=environment, host=host,
                                         authorization=authorization)
        else:
            self.config = config

        self.global_configuration = GlobalConfiguration(self.config)\
            .global_errors(BaseController.global_errors())\
            .base_uri_executor(self.config.get_base_uri)\
            .user_agent(BaseController.user_agent(), BaseController.user_agent_parameters())
        self.initialize_auth_managers(self.global_configuration)

        self.global_configuration = self.global_configuration.auth_managers(self.auth_managers)

    def initialize_auth_managers(self, global_config):
        http_client_config = global_config.get_http_client_configuration()
        self.auth_managers = { key: None for key in ['global']}
        self.auth_managers['global'] = CustomHeaderAuthentication(http_client_config.authorization)
        return self.auth_managers



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from enum import Enum
from ctddocumentation.api_helper import APIHelper
from apimatic_core.http.configurations.http_client_configuration import HttpClientConfiguration
from apimatic_requests_client_adapter.requests_client import RequestsClient


class Environment(Enum):
    """An enum for SDK environments"""
    PRODUCTION = 0


class Server(Enum):
    """An enum for API servers"""
    DEFAULT = 0


class Configuration(HttpClientConfiguration):
    """A class used for configuring the SDK by a user.
    """

    @property
    def environment(self):
        return self._environment

    @property
    def host(self):
        return self._host

    @property
    def authorization(self):
        return self._authorization

    def __init__(
        self, http_client_instance=None,
        override_http_client_configuration=False, http_call_back=None,
        timeout=60, max_retries=0, backoff_factor=2,
        retry_statuses=[408, 413, 429, 500, 502, 503, 504, 521, 522, 524],
        retry_methods=['GET', 'PUT'], environment=Environment.PRODUCTION,
        host='HostValue', authorization='TODO: Replace'
    ):
        super().__init__(http_client_instance, override_http_client_configuration, http_call_back, timeout, max_retries,
                         backoff_factor, retry_statuses, retry_methods)
        # Current API environment
        self._environment = environment

        # host value
        self._host = host

        # TODO: Replace
        self._authorization = authorization

        # The Http Client to use for making requests.
        super().set_http_client(self.create_http_client())

    def clone_with(self, http_client_instance=None,
                   override_http_client_configuration=None, http_call_back=None,
                   timeout=None, max_retries=None, backoff_factor=None,
                   retry_statuses=None, retry_methods=None, environment=None,
                   host=None, authorization=None):
        http_client_instance = http_client_instance or super().http_client_instance
        override_http_client_configuration = override_http_client_configuration or super().override_http_client_configuration
        http_call_back = http_call_back or super().http_callback
        timeout = timeout or super().timeout
        max_retries = max_retries or super().max_retries
        backoff_factor = backoff_factor or super().backoff_factor
        retry_statuses = retry_statuses or super().retry_statuses
        retry_methods = retry_methods or super().retry_methods
        environment = environment or self.environment
        host = host or self.host
        authorization = authorization or self.authorization
        return Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            environment=environment, host=host, authorization=authorization
        )

    def create_http_client(self):
        return RequestsClient(
            timeout=super().timeout, max_retries=super().max_retries,
            backoff_factor=super().backoff_factor, retry_statuses=super().retry_statuses,
            retry_methods=super().retry_methods,
            http_client_instance=super().http_client_instance,
            override_http_client_configuration=super().override_http_client_configuration,
            response_factory=super().http_response_factory
        )

    # All the environments the SDK can run in
    environments = {
        Environment.PRODUCTION: {
            Server.DEFAULT: 'https://{Host}'
        }
    }

    def get_base_uri(self, server=Server.DEFAULT):
        """Generates the appropriate base URI for the environment and the
        server.

        Args:
            server (Configuration.Server): The server enum for which the base
            URI is required.

        Returns:
            String: The base URI.

        """
        parameters = {
            "Host": {'value': self.host, 'encode': False},
        }

        return APIHelper.append_url_with_template_parameters(
            self.environments[self.environment][server], parameters
        )



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper
from ctddocumentation.models.entity import Entity


class ActivitiesObject(object):

    """Implementation of the 'ActivitiesObject' model.

    TODO: type model description here.

    Attributes:
        description (string): TODO: type description here.
        display_type (string): TODO: type description here.
        entity (Entity): TODO: type description here.
        id (int): TODO: type description here.
        resource_id (string): TODO: type description here.
        site_id (int): TODO: type description here.
        site_name (string): TODO: type description here.
        timestamp (string): TODO: type description here.
        mtype (int): TODO: type description here.
        user_id (string): TODO: type description here.
        user_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description": 'description',
        "display_type": 'display_type',
        "entity": 'entity',
        "id": 'id',
        "resource_id": 'resource_id',
        "site_id": 'site_id',
        "site_name": 'site_name',
        "timestamp": 'timestamp',
        "mtype": 'type',
        "user_id": 'user_id',
        "user_name": 'user_name'
    }

    _optionals = [
        'description',
        'display_type',
        'entity',
        'id',
        'resource_id',
        'site_id',
        'site_name',
        'timestamp',
        'mtype',
        'user_id',
        'user_name',
    ]

    def __init__(self,
                 description=APIHelper.SKIP,
                 display_type=APIHelper.SKIP,
                 entity=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 resource_id=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 site_name=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 user_id=APIHelper.SKIP,
                 user_name=APIHelper.SKIP):
        """Constructor for the ActivitiesObject class"""

        # Initialize members of the class
        if description is not APIHelper.SKIP:
            self.description = description 
        if display_type is not APIHelper.SKIP:
            self.display_type = display_type 
        if entity is not APIHelper.SKIP:
            self.entity = entity 
        if id is not APIHelper.SKIP:
            self.id = id 
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if site_name is not APIHelper.SKIP:
            self.site_name = site_name 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if user_id is not APIHelper.SKIP:
            self.user_id = user_id 
        if user_name is not APIHelper.SKIP:
            self.user_name = user_name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        display_type = dictionary.get("display_type") if dictionary.get("display_type") else APIHelper.SKIP
        entity = Entity.from_dictionary(dictionary.get('entity')) if 'entity' in dictionary.keys() else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        resource_id = dictionary.get("resource_id") if dictionary.get("resource_id") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        site_name = dictionary.get("site_name") if dictionary.get("site_name") else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        user_id = dictionary.get("user_id") if dictionary.get("user_id") else APIHelper.SKIP
        user_name = dictionary.get("user_name") if dictionary.get("user_name") else APIHelper.SKIP
        # Return an object of this model
        return cls(description,
                   display_type,
                   entity,
                   id,
                   resource_id,
                   site_id,
                   site_name,
                   timestamp,
                   mtype,
                   user_id,
                   user_name)



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SpecialHintEnum(object):

    """Implementation of the 'SpecialHint' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAMEUNICASTVALUE0: TODO: type description here.
        ENUM_NAMEBROADCASTVALUE1: TODO: type description here.
        ENUM_NAMEMULTICASTVALUE2: TODO: type description here.
        ENUM_NAMEMITM VIRTUALVALUE3: TODO: type description here.
        ENUM_NAMEEXTERNALVALUE4: TODO: type description here.

    """

    ENUM_NAMEUNICASTVALUE0 = '{"name":"Unicast","value":0}'

    ENUM_NAMEBROADCASTVALUE1 = '{"name":"Broadcast","value":1}'

    ENUM_NAMEMULTICASTVALUE2 = '{"name":"Multicast","value":2}'

    ENUM_NAMEMITM_VIRTUALVALUE3 = '{"name":"Mitm Virtual","value":3}'

    ENUM_NAMEEXTERNALVALUE4 = '{"name":"External","value":4}'



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or
from ctddocumentation.models.get_license_details_response import GetLicenseDetailsResponse
from ctddocumentation.models.update_license_response import UpdateLicenseResponse


class LicenseController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(LicenseController, self).__init__(config)

    def get_license_details(self,
                            site_id):
        """Does a GET request to /ranger/license/{site_id}.

        Admin users can get the current license details

        Args:
            site_id (int): On which site to operate

        Returns:
            GetLicenseDetailsResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/license/{site_id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('site_id')
                            .value(site_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetLicenseDetailsResponse.from_dictionary)
        ).execute()

    def add_license(self,
                    site_id,
                    body):
        """Does a POST request to /ranger/license/{site_id}.

        Add License

        Args:
            site_id (int): On which site to operate
            body (LicenseRequest): Set license

        Returns:
            UpdateLicenseResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/license/{site_id}')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('site_id')
                            .value(site_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateLicenseResponse.from_dictionary)
        ).execute()

    def update_license(self,
                       site_id,
                       body):
        """Does a PUT request to /ranger/license/{site_id}.

        Update license

        Args:
            site_id (int): On which site to operate
            body (LicenseRequest): Set license

        Returns:
            UpdateLicenseResponse: Response from the API. Successful
                Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/license/{site_id}')
            .http_method(HttpMethodEnum.PUT)
            .template_param(Parameter()
                            .key('site_id')
                            .value(site_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateLicenseResponse.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from ctddocumentation.api_helper import APIHelper
from ctddocumentation.configuration import Server
from ctddocumentation.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from ctddocumentation.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.and_auth_group import And
from apimatic_core.authentication.multiple.or_auth_group import Or
from ctddocumentation.models.get_custom_attribute_categories_response import GetCustomAttributeCategoriesResponse


class CustomAttributesCategoriesController(BaseController):

    """A Controller to access Endpoints in the ctddocumentation API."""
    def __init__(self, config):
        super(CustomAttributesCategoriesController, self).__init__(config)

    def get_custom_attribute_categories(self,
                                        page=None,
                                        per_page=None,
                                        id__exact=None,
                                        site_id__exact=None,
                                        name__contains=None,
                                        name__icontains=None,
                                        description__icontains=None,
                                        description__contains=None,
                                        sort=None):
        """Does a GET request to /ranger/custom_attribute_categories.

        Get Custom Attribute Categories

        Args:
            page (int, optional): TODO: type description here.
            per_page (int, optional): TODO: type description here.
            id__exact (int, optional): TODO: type description here.
            site_id__exact (int, optional): TODO: type description here.
            name__contains (string, optional): TODO: type description here.
            name__icontains (string, optional): TODO: type description here.
            description__icontains (string, optional): TODO: type description
                here.
            description__contains (string, optional): TODO: type description
                here.
            sort (Sort5Enum, optional): TODO: type description here.

        Returns:
            GetCustomAttributeCategoriesResponse: Response from the API.
                Successful Operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/ranger/custom_attribute_categories')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('id__exact')
                         .value(id__exact))
            .query_param(Parameter()
                         .key('site_id__exact')
                         .value(site_id__exact))
            .query_param(Parameter()
                         .key('name__contains')
                         .value(name__contains))
            .query_param(Parameter()
                         .key('name__icontains')
                         .value(name__icontains))
            .query_param(Parameter()
                         .key('description__icontains')
                         .value(description__icontains))
            .query_param(Parameter()
                         .key('description__contains')
                         .value(description__contains))
            .query_param(Parameter()
                         .key('sort')
                         .value(sort))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('global'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetCustomAttributeCategoriesResponse.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.api_helper import APIHelper


class IndicatorInfo(object):

    """Implementation of the 'IndicatorInfo' model.

    TODO: type model description here.

    Attributes:
        id (int): TODO: type description here.
        points (int): TODO: type description here.
        site_id (int): TODO: type description here.
        mtype (int): TODO: type description here.
        description (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "points": 'points',
        "site_id": 'site_id',
        "mtype": 'type',
        "description": 'description'
    }

    _optionals = [
        'id',
        'points',
        'site_id',
        'mtype',
        'description',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 points=APIHelper.SKIP,
                 site_id=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 description=APIHelper.SKIP):
        """Constructor for the IndicatorInfo class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if points is not APIHelper.SKIP:
            self.points = points 
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if description is not APIHelper.SKIP:
            self.description = description 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        points = dictionary.get("points") if dictionary.get("points") else APIHelper.SKIP
        site_id = dictionary.get("site_id") if dictionary.get("site_id") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   points,
                   site_id,
                   mtype,
                   description)
